theme_est: Brand Estonia theme

Description Usage Arguments Details Examples

Description

A theme inspired by the Estonian brand platform.

Usage

1
theme_est(base_size = 10)

Arguments

base_size

Base font size.

Details

The Aino typeface is not included in the package because of its terms and conditions. You can download the typeface from here. In order to use the font, you need to import it by calling the import_aino_fonts function.

Examples

1
2
3
4
5
6
data(funding)
x11() # open graphics device
ggplot(funding, aes(x=factor(year), y=total_raised_capital)) +
  geom_bar(stat="identity") +
  ggtitle("Investments raised by Estonian startups") +
  theme_est()

tanelp/ggest documentation built on June 21, 2019, 12:38 a.m.