Description Usage Arguments Details Examples
A theme inspired by the Estonian brand platform.
1 | theme_est(base_size = 10)
|
base_size |
Base font size. |
The Aino typeface is not included in the package because of its terms and conditions.
You can download the typeface from here.
In order to use the font,
you need to import it by calling the import_aino_fonts function.
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.